@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11459 2019-04-16 18:20:57Z Lavender $
+# $Id: __init__.py 11430 2019-04-10 05:13:37Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-17 03:20:57 +0900 (週三, 17 四月 2019) $
-# $Revision: 11459 $
+# $Date: 2019-04-10 13:13:37 +0800 (週三, 10 四月 2019) $
+# $Revision: 11430 $
 
 from __future__ import print_function
 
@@ -25,7 +25,7 @@ import importlib
 from .Patch import attachURLs, attachDebugURLs
 from .Util import update, populateEnvToSettings
 
-from Iuppiter.DjangoUtil import extendInstalledApps, DJANGO_VERSION
+from Iuppiter.DjangoUtil import extendInstalledApps
 
 # Default SERVER_MODE values.
 DEVELOPMENT = 1
@@ -38,6 +38,14 @@ SERVER_MODES = {
     'PRODUCTION': PRODUCTION,
 }
 
+try:
+    import django
+
+    DJANGO_VERSION = (django.VERSION[0] * 100 + django.VERSION[1] * 10 +
+                      django.VERSION[2])
+except ImportError:
+    warnings.warn("Unable to import django, many Iuno packages require it.")
+
 def createWSGIHandler(cloudLogging=False, settingsModule=None, siteDir=None):
     """
     Create WSGIHandler for django and automatically initialize path settings.
@@ -658,7 +666,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     #=========================================================================
     # Django plugins.
-    if DJANGO_VERSION >= 11100: # django >= 1.11
+    if DJANGO_VERSION >= 210: # django >= 1.11
         MIDDLEWARE = 'MIDDLEWARE'
     else:
         MIDDLEWARE = 'MIDDLEWARE_CLASSES'
