@@ -22,10 +22,15 @@ import platform
 from termcolor import colored, cprint
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
+from django.core.management import call_command
 
 from Iuno import DEVELOPMENT, STAGE, PRODUCTION
 from Iuppiter.Util import classForName
 
+from Iuppiter.Logging import createLogger
+
+logger = createLogger(__name__)
+
 class Command(BaseCommand):
     
     help = 'Scan all app Deploy.py and execute [name] function.'
@@ -49,21 +54,32 @@ class Command(BaseCommand):
                 sysStr = platform.system()
                 if sysStr == "Linux":
                     os.system("convmv -f big5 -t utf8 -r --notest media")
+                    
+        # Iuno initialdata
+        initialData = hasattr(settings, 'IUNO_INITIAL_DATA')
+        
+        if initialData:
+            initialData = settings.IUNO_INITIAL_DATA
+            if os.path.exists(initialData):
+                call_command('loaddata', initialData)
 
         # get sites
-        from django.contrib.sites.models import Site
-        
-        site = Site.objects.filter(id=settings.SITE_ID)[0]    
-        siteNames = hasattr(settings, 'IUNO_SITE_DOMAIN_NAMES')
-        if siteNames:
-            siteNames = settings.IUNO_SITE_DOMAIN_NAMES
-            if settings.SERVER_MODE == PRODUCTION:
-                site.domain = siteNames[PRODUCTION]
-            elif settings.SERVER_MODE == STAGE:
-                site.domain = siteNames[STAGE]
-            else:
-                site.domain = siteNames[DEVELOPMENT]
-            site.save()
+        try:
+            from django.contrib.sites.models import Site
+            
+            site = Site.objects.filter(id=settings.SITE_ID)[0]    
+            siteNames = hasattr(settings, 'IUNO_SITE_DOMAIN_NAMES')
+            if siteNames:
+                siteNames = settings.IUNO_SITE_DOMAIN_NAMES
+                if settings.SERVER_MODE == PRODUCTION:
+                    site.domain = siteNames[PRODUCTION]
+                elif settings.SERVER_MODE == STAGE:
+                    site.domain = siteNames[STAGE]
+                else:
+                    site.domain = siteNames[DEVELOPMENT]
+                site.save()
+        except Exception as e:
+            logger.error(str(e))
 
         # other
         for app in settings.INSTALLED_APPS:
