@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11459 2019-04-16 18:20:57Z Lavender $
+# $Id: __init__.py 11452 2019-04-13 15:00:15Z Andy $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2019-04-17 03:20:57 +0900 (週三, 17 四月 2019) $
-# $Revision: 11459 $
+# $Author: Andy $ (last)
+# $Date: 2019-04-13 23:00:15 +0800 (週六, 13 四月 2019) $
+# $Revision: 11452 $
 
 import os
 import sys
@@ -28,8 +28,7 @@ import hashlib
 from collections import OrderedDict
 
 from Iuppiter.Encoding import utf8
-from Iuppiter.DjangoUtil import DJANGO_VERSION
-from Iuno import warnWithout, update, require
+from Iuno import warnWithout, update, require, DJANGO_VERSION
 from Iuppiter.DjangoUtil import (extendInstalledApps, 
                                  extendMiddlewareClasses, 
                                  extendTemplateContextProcessors,
@@ -718,7 +717,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
         )
 
         payment = mpg.createPayment(data)
-        if DJANGO_VERSION >= 11100: # django >= 1.11
+        if DJANGO_VERSION >= 210: # django >= 1.11
             context = {'spgateway': payment,}
         else:
             context = Context({'spgateway': payment,})
@@ -825,7 +824,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
         else:
             needExtraData = True
 
-        if DJANGO_VERSION >= 11100: # django >= 1.11
+        if DJANGO_VERSION >= 210: # django >= 1.11
             context = {
                 'apiUrl': apiUrl,
                 'chantID': settings.ECPAY_API_MERCHANT_ID,
@@ -925,7 +924,8 @@ def buildAPIForm(submission, request, apiName, extra={}):
         data["CheckMacValue"] = checkValue
 
         temp = get_template('shop/payment/EcpayLogistic.html')
-        if DJANGO_VERSION >= 11100: # django >= 1.11
+        if DJANGO_VERSION >= 210: # django >= 1.11
+            print("jiji")
             context = {
                 'apiUrl': apiUrl,
                 'data': data,
