@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_tree.py 11314 2018-12-14 05:31:25Z Kevin $
+# $Id: build_tree.py 11449 2019-04-13 12:42:08Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,13 +11,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $
-# $Date: 2018-12-14 14:31:25 +0900 (週五, 14 十二月 2018) $
-# $Revision: 11314 $
+# $Author: Lavender $
+# $Date: 2019-04-13 20:42:08 +0800 (週六, 13 四月 2019) $
+# $Revision: 11449 $
 
 import os
 
 from django.conf import settings
+from django.db import transaction
 from django.core.management.base import BaseCommand
 
 from Iuno.template_editor.models import Static, Template, FOLDER, FILE
@@ -45,6 +46,7 @@ class Command(BaseCommand):
         self.createNode(self.staticPath, Static)
         self.createNode(self.templatePath, Template)
 
+    @transaction.atomic
     def createNode(self, path, model, parent=None):
 
         if self.staticPath in path:
